==> kdesvn_0.14.1.orig.tar.gz: kdesvn-0.14.1/src/ksvnwidgets/diffsyntax.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Rajko Albrecht                                  *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef _DIFFSYNTAX_H
#define _DIFFSYNTAX_H

#include <qsyntaxhighlighter.h>
#include <qregexp.h>
#include <qfont.h>

class QTextEdit;
class QString;
class QColor;

class DiffSyntax : public QSyntaxHighlighter
{
public:
     DiffSyntax(QTextEdit*);
    virtual int highlightParagraph ( const QString & text, int endStateOfLastPara );
    virtual  ~DiffSyntax();
};

#endif

==> kdesvn_1.2.4.orig.tar.gz: kdesvn-1.2.4/src/ksvnwidgets/diffsyntax.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Rajko Albrecht                                  *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef _DIFFSYNTAX_H
#define _DIFFSYNTAX_H

#include <QSyntaxHighlighter>


class DiffSyntax : public QSyntaxHighlighter
{
public:
    DiffSyntax(QTextEdit*);
//     virtual int highlightParagraph ( const QString & text, int endStateOfLastPara );
    virtual  ~DiffSyntax();

    protected:
        void highlightBlock(const QString &aText);
};

#endif
